@@ -11,9 +11,8 @@ write not only xml output.
 import os
 from collections.abc import Iterable
 import numpy as np
-from ase.dft.kpoints import monkhorst_pack
+from TB2J.kpoints import monkhorst_pack
 import pickle
-from ase.cell import Cell
 from TB2J import __version__
 from datetime import datetime
 import matplotlib.pyplot as plt
@@ -222,18 +221,15 @@ Generation time: {now.strftime("%y/%m/%d %H:%M:%S")}
         from TB2J.io_exchange.io_multibinit import write_multibinit
         write_multibinit(self, path=path)
 
-    def write_Jq(self, kmesh, path, **kwargs):
+    def write_Jq(self, kmesh,  path, gamma=True, output_fname='EigenJq.txt',  **kwargs):
         from TB2J.spinham.spin_api import SpinModel
         from TB2J.io_exchange.io_txt import write_Jq_info
         m = SpinModel(fname=os.path.join(path, 'Multibinit', 'exchange.xml'))
         m.set_ham(**kwargs)
-        kpts1 = monkhorst_pack(kmesh)
-        bp = Cell(self.atoms.cell).bandpath(npoints=400)
-        kpts2 = bp.kpts
-        kpts = np.vstack([kpts1, kpts2])
+        kpts = monkhorst_pack(kmesh, gamma_center=gamma)
 
         evals, evecs = m.ham.solve_k(kpts, Jq=True)
-        with open(os.path.join(path, 'summary.txt'), 'w') as myfile:
+        with open(os.path.join(path, output_fname), 'w') as myfile:
             myfile.write("=" * 60)
             myfile.write("\n")
             myfile.write("Generated by TB2J %s.\n" % (__version__))
